#
# spec file for package python-ansible-compat
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%if 0%{?suse_version} >= 1650
# Tumbleweed
# only works with the python version which the package 'ansible' uses
%define pythons python3
%endif

Name:           python-ansible-compat
Version:        25.1.4
Release:        1.1
Summary:        Compatibility shim for Ansible 2.9 and newer
License:        MIT
URL:            https://github.com/ansible-community/ansible-compat
Source:         https://github.com/ansible-community/ansible-compat/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION test
# https://github.com/ansible/ansible-compat/blob/main/.config/requirements.in
BuildRequires:  ansible-core >= 2.14
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module jsonschema >= 4.17.3}
BuildRequires:  %{python_module subprocess-tee >= 0.4.1}
# https://github.com/ansible/ansible-compat/blob/main/.config/requirements-test.in
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytest-instafail}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest-plus}
# /SECTION
BuildRequires:  fdupes
BuildRequires:  python-rpm-generators
Requires:       ansible-core >= 2.16
Requires:       python-PyYAML
Requires:       python-jsonschema >= 4.17.3
Requires:       python-packaging
Requires:       python-subprocess-tee >= 0.4.1
%{?python_enable_dependency_generator}
BuildArch:      noarch
%python_subpackages

%description
Facilitate working with various versions of Ansible 2.9 and newer.

%prep
%setup -q -n ansible-compat-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# excluding tests requiring internet connection
IGNORED_CHECKS="test_install_collection"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_install_collection_dest"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_prepare_environment_with_collections"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_prerun_reqs_v1"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_prerun_reqs_v2"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_require_collection"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_require_collection_no_cache_dir"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_require_collection_wrong_version"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_runtime_example"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_runtime_require_module"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_scan_sys_path[isolatedF-scanF-raises_not_foundT]"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_scan_sys_path[isolatedF-scanT-raises_not_foundF]"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_scan_sys_path[isolatedT-scanF-raises_not_foundT]"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_scan_sys_path[isolatedT-scanT-raises_not_foundT]"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_scan_sys_path[scanF-raises_not_foundT]"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_scan_sys_path[scanT-raises_not_foundF]"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_upgrade_collection"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_runtime_has_playbook"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_load_plugins[modules]"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_get_cache_dir_relative"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_ro_venv"
# tests that need network connectivity
IGNORED_CHECKS="${IGNORED_CHECKS} or test_scan_sys_path[0]"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_scan_sys_path[1]"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_scan_sys_path[disabled]"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_scan_sys_path[enabled]"
# Disable checks on test names: https://github.com/pytest-dev/pytest-plus#user-content-avoiding-problematic-test-identifiers https://github.com/ansible/ansible-compat/issues/340
export PYTEST_CHECK_TEST_ID_REGEX=0
%pytest -k "not (${IGNORED_CHECKS})"

%files %{python_files}
%{python_sitelib}/ansible_compat
%{python_sitelib}/ansible_compat-%{version}.dist-info
%doc README.md
%license LICENSE

%changelog
* Wed Feb 19 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 25.1.4:
  * Bugfixes
  - Add site-package to the end of collection inclusion path
    (#470) @ssbarnea
* Tue Feb 18 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 25.1.3:
  * Bugfixes
  - Avoid get_cache_dir errors with read only virtualenvs (#465)
    @ssbarnea
* Fri Feb  7 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 25.1.2:
  * Bugfixes
  - Avoid get_cache_dir errors with read only virtualenvs (#457)
    @ssbarnea
  - Simplify module presence testing (#460) @ssbarnea
  - Fix grammatical error in collection path info message (#456)
    @bluikko
* Tue Jan 28 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 25.1.1:
  * Bugfixes
  - Ensure that cache directory is writable (#453) @ssbarnea
* Mon Jan 27 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 25.1.0:
  * Major
  - Inject venv site-packages at the top of collection path (test
    isolation) (#447) @ssbarnea
  - Fail if old ANSIBLE_COLLECTIONS_PATHS is detected (#449)
    @ssbarnea
  * Bugfixes
  - Patch #449 to use ANSIBLE_COLLECTIONS_PATH (#450) @ssbarnea
* Wed Jan 15 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 25.0.0:
  * Major
  - Support ansible 2.18, drop 2.14/2.15 and py39 (#443) @ssbarnea
  * Bugfixes
  - Change cache_dir location to prefer venv and project_directory (#439) @ssbarnea
  - Enable toml-sort-fix (#442) @ssbarnea
  - Refactor search_galaxy_paths to use pathlib (#437) @ssbarnea
* Wed Nov 13 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.10.0:
  * Enhancements
  - Add support for py313 (#416) @ssbarnea
  * Bugfixes
  - Re-init plugin loader after collections installation (#411) (#412) @irozet12
* Sat Sep 21 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.9.1:
  * Bugfixes
  - Avoid running prepare ansible paths twice (#409) @ssbarnea
  - Avoid duplicate paths when path injection (#407) @ssbarnea
  - Provide more detail on multiple collection installs (#405)
    @mrgum
* Thu Sep 12 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.9.0:
  * Enhancements
  - Add communication details (#400) @oraNod
  * Bugfixes
  - Fix upload-artifact action to work with v4.4 and newer (#403)
    @alisonlhart
* Mon Aug 19 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.8.0:
  * Bugfixes
  - Updated dead links in constants.py (#397) @tanwigeetika1618
* Thu Jul 11 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.7.0:
  * Bugfixes
  - Minor code quality improvements (#390) @cidrblock
* Fri Jun  7 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.6.1:
  * Bugfixes
  - Allow the caller to set the ANSIBLE_COLLECTIONS_PATH (#388)
    @cidrblock
  - Don't nuke the collections path (#387) @cidrblock
* Thu May 30 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.6.0:
  * Enhancements
  - Drop support for Ansible 2.12 and 2.13 (#380) @ssbarnea
  * Bugfixes
  - Make collection location cache_dir aware (#384) @ssbarnea
  - Correctly identify the installed collections when duplicates
    exist (#379) @ssbarnea
  - Increase coverage (#378) @ssbarnea
  - Removed leftover code related to ansible-core before 2.14
    (#382) @ssbarnea
* Tue May 14 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.5.1:
  * Minor Changes
  - Add has_playbook method to Runtime (#364) @ssbarnea
  * Bugfixes
  - Fix packaging version to recognize pre-release versions
    (#371) @ssbarnea
  - Update requirements (#365) @ssbarnea
  - Allow dashes in role namespaces (#355) @sur5r
  - If project_dir is passed, locate requirements within that
    directory (#339) @audgirka
* Sat Mar 16 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 4.1.12:
  * Bugfixes
  - Allow dashes in role namespaces (#355) @sur5r
  - If project_dir is passed, locate requirements within that
    directory (#339) @audgirka
* Wed Jan 10 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 4.1.11:
  * Bugfixes
  - Allow more control over verbosity when calling ansible-galaxy
    (#278) @ziegenberg
  - Fix collection installation with custom project_dir (#343)
    @ssbarnea
  - Fix collection installation bug when having custom config
    (#344) @ssbarnea
  - Add support for python 3.12 (#336) @ssbarnea
  - Remove isolated option while adding sys.path (#335)
    @shatakshiiii
* Fri Nov 24 2023 Sebastian Wagner <sebix@sebix.at>
- disable pytest's test name check
  https://github.com/ansible/ansible-compat/issues/340
* Wed Sep  6 2023 Johannes Kastl <kastl@b1-systems.de>
- fix BuildRequires and Requires
- ignore 4 new checks that need internet connectivity
  * test_scan_sys_path[isolatedT-scanT-raises_not_foundT]
  * test_scan_sys_path[isolatedT-scanF-raises_not_foundT]
  * test_scan_sys_path[isolatedF-scanT-raises_not_foundF]
  * test_scan_sys_path[isolatedF-scanF-raises_not_foundT]
- update to 4.1.10:
  * Bugfixes
  - Catch empty collection lists (#332) @lod
* Wed Sep  6 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 4.1.9:
  * Bugfixes
  - Automatically add --pre when installing collections from git
    repositories @ssbarnea
* Wed Sep  6 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 4.1.8:
  * Bugfixes
  - Revise site packages collection search test (#325) @cidrblock
  - Add only those sys.paths which contain an ansible_collections
    directory path (#322) @ajinkyau
  - Allow git dependencies in galaxy.yml files (#321) @ssbarnea
* Wed Sep  6 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 4.1.7:
  * Bugfixes
  - Add `sys.path` to collection paths (#318) @cidrblock
* Wed Sep  6 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 4.1.6:
  * Bugfixes
  - Fix logic on prepare environment (#310) @ssbarnea
  - Add smoke testing with ansible-lint (#312) @ssbarnea
  - Adapt collection install test to pass with ansible-core
    2.15.3 changes (#313) @ssbarnea
  - Support meta main yaml extension (#304) @zhan9san
* Fri Jul 21 2023 Johannes Kastl <kastl@b1-systems.de>
- releases 4.1.3 and 4.1.4 were yanked
- update to 4.1.5:
  * Bugfixes
  - Fix find roles inside collection repository (#297) @ajinkyau
  - Enable packit rpm packaging (#292) @ssbarnea
* Fri Jul 21 2023 Steve Kowalik <steven.kowalik@suse.com>
- Remove unneeded BuildRequires on setuptools_scm_git_archive.
- Do not use a glob in %%files
* Thu Jun  1 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 4.1.2:
  * Bugfixes
  - Avoid stdout pollution cause by ansible logging (#287)
    @ajinkyau
* Tue May 30 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 4.1.1:
  * Bugfixes
  - Disable Ansible debug mode for sub-commands (#284) @ssbarnea
  - Log retry attempt only when doing retries (#283) @ssbarnea
* Wed May 24 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 4.1.0:
  * Minor Changes
  - Enable access to available plugins (#277) @ssbarnea
  * Bugfixes
  - Avoid creating ~/.ansible/collections (#280) @ssbarnea
* Mon May 22 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 4.0.5:
  * Bugfixes
  - Improve requirements.yml detection (#275) @ssbarnea
- update to 4.0.4:
  * Bugfixes
  - Allow use of * version on dependencies (#268) @ssbarnea
- update to 4.0.3:
  * Bugfixes
  - Automatically install tests/requirements.yml when found
    (#266) @ssbarnea
  - Also install requirements from galaxy.yml files (#265)
    @ssbarnea
  - Include original message in AnsibleWarning (#264) @ssbarnea
- update to 4.0.2:
  * Bugfixes
  - Revert to previous behavior for ansible_collections_path
    (#261) @ajinkyau
- update to 4.0.1 (4.0.0 does not exist):
  * Major Changes
  - Rename Runtime.exec to Runtime.run (#256) @ssbarnea
  - Introduce use of JSON recursive type (#253) @ssbarnea
  - ruff: Make optional arguments keyword-only (#251) @ssbarnea
  - Finish pathlib migration (#245) @ssbarnea
  - Make Runtime.project_dir use Path (#244) @ssbarnea
  - Migrate some functions to use Path (#243) @ssbarnea
  - Make Runtime.cache_dir use Path (#240) @ssbarnea
  - Remove support for py38 (#239) @ssbarnea
  * Minor Changes
  - Monkeypatch ansible core Display.warning (#238) @ssbarnea
  * Bugfixes
  - Use YAML safe loader instead of full loader (#255) @ssbarnea
  - Use dataclass sorting for json schema errors (#254) @ssbarnea
  - ruff: Address more skips (#249) @ssbarnea
  - ruff: address TRY and T201 (#248) @ssbarnea
  - ruff: Address EM (#247) @ssbarnea
  - Convert more code to pathlib (#242) @ssbarnea
* Fri May 19 2023 Johannes Kastl <kastl@b1-systems.de>
- change python version on Leap15/SLES15 to python3.11 to use the
  new stack supported by SUSE
* Tue May 16 2023 Johannes Kastl <kastl@b1-systems.de>
- rework %%if condition to work with new sle15_python_module_pythons
  macro on SLES15/Leap15
* Fri Apr 14 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 3.0.2:
  * Change install_collection to avoid use of -p (#233) @ssbarnea
  * Correct documentation links (#232) @ssbarnea
  * Avoid using -p option with ansible-galaxy install (#230)
    @ssbarnea
  * Fix collection loading (#223) @apatard
* Tue Jan 31 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 3.0.0:
  * Major Changes
  - Require ansible-core 2.12 or newer (#215) @ssbarnea
  * Minor Changes
  - Address ansible 2.15 compatibility related to AnsibleCollectionConfig (#213) @ssbarnea
  * Bugfixes
  - Required subprocess-tee>=0.4.1 (#211) @ssbarnea
- update to 3.0.1:
  * Bugfixes
  - Avoid double initialization of ansible runtime (#218) @ssbarnea
  - Update README.md for 3.0.0 release (#217) @ianw
* Sun Dec 18 2022 Johannes Kastl <kastl@b1-systems.de>
- ignore deprecation warning for 'There is no current event loop'
* Sat Dec 10 2022 Johannes Kastl <kastl@b1-systems.de>
- update to 2.2.7:
  * Bugfixes
  - Restore offline more functionality (#201) @ssbarnea
* Thu Dec  1 2022 Johannes Kastl <kastl@b1-systems.de>
- update to 2.2.6:
  * Bugfixes
  - Adopt PEP-621 for packaging (#195) @ssbarnea
  - Revert "Avoid running galaxy on offline mode (#180)" (#192) @ssbarnea
* Fri Nov 25 2022 Johannes Kastl <kastl@b1-systems.de>
- rework spec file to define %%pythons to python310 for Leap15 and SLES15,
  using the python version 3.10 that ansible is built against
- add explicit Requires for python*-subprocess-tee, that is not being added
  automatically
* Fri Nov 18 2022 Johannes Kastl <kastl@b1-systems.de>
- update to 2.2.5:
  * Bugfixes
  - Make galaxy installation verbose (#190) @ssbarnea
  - Log current directory before running galaxy install (#188) @ssbarnea
  - Update build-system dependency for setuptools-scm to >= 7.0.0 (#186) @dvzrv
  - Update devtools repo url (#185) @ssbarnea
* Tue Nov 15 2022 Johannes Kastl <kastl@b1-systems.de>
- update to 2.2.4:
  * Bugfixes
  - Avoid running galaxy on offline mode (#180) @ssbarnea
* Mon Oct 31 2022 Johannes Kastl <kastl@b1-systems.de>
- update to 2.2.3:
  * Bugfixes
  - Correct offline cli arg support check (#178) @ssbarnea
* Mon Oct 31 2022 Johannes Kastl <kastl@b1-systems.de>
- update to 2.2.2:
  * Bugfixes
  - Add packaging to dependencies (#173) @ssbarnea
  - Pass offline argument to galaxy command when needed (#172) @ssbarnea
* Sun Sep 25 2022 Johannes Kastl <kastl@b1-systems.de>
- update to 2.2.1:
  * Bugfixes
  - Avoid galaxy install failure with already symlinked collections (#166) @ssbarnea
  - Avoid python warning about unknown warning category (#164) @ssbarnea
* Thu Jul 28 2022 Johannes Kastl <kastl@b1-systems.de>
- update to 2.2.0:
  * Minor Changes
  - Allow installation of pre-released collections (#157) @ssbarnea
  - Add support for python 3.11 (#155) @ssbarnea
  * Bugfixes
  - Refactor schema testing (#152) @ssbarnea
  - Use jsonschema 4.6.0 (#153) @ssbarnea
  - Avoid CryptographyDeprecationWarning from paramiko (#150) @ssbarnea
* Tue Jun 14 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 2.1.0:
  - Minor Changes
  - Add module to work with schemas (#143) @ssbarnea
  - Bugfixes
  - Expose role_name_check in prepare_environment (#147) @zhan9san
  - Install role in cache dir (#135) @zhan9san
  - Prevent occasional FileExistsError with symlink recreation (#145) @ssbarnea
* Sun May 22 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.0.4:
  - Add support for tower requirements (#140)
  - Add offline option to prepare_environment (#138)
  Fixes: #137
* Fri Apr  1 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Add missing build dependency setuptools_scm.
* Tue Mar 29 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 2.0.2:
  - Ensure get_cache_dir works with relative paths (#131)
  - Make cache_key portable (#127)
  This will help getting the behavior more portable across different
  systems, as the cache key for specific project name should be the
  same, regardless location of user home directory or the source code
  location.
  - Correct pylint version (#128)
  We previously used unreleased version of pylint.
* Tue Mar 15 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Initial package for version 2.0.0.
